Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(511)

Unified Diff: snapshot/minidump/minidump_string_list_reader.h

Issue 972383002: snapshot: Add a minimal ModuleSnapshotMinidump and accessor from ProcessSnapshotMinidump (Closed) Base URL: https://chromium.googlesource.com/crashpad/crashpad@master
Patch Set: Add NOTREACHED() comments Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: snapshot/minidump/minidump_string_list_reader.h
diff --git a/snapshot/minidump/minidump_string_reader.h b/snapshot/minidump/minidump_string_list_reader.h
similarity index 53%
copy from snapshot/minidump/minidump_string_reader.h
copy to snapshot/minidump/minidump_string_list_reader.h
index e5667ec242bc8f53d570179f4eddfeb2f8cb90f7..2521605a1cfa2e66c9fd6f45d5384ce5eda011cf 100644
--- a/snapshot/minidump/minidump_string_reader.h
+++ b/snapshot/minidump/minidump_string_list_reader.h
@@ -12,29 +12,31 @@
// See the License for the specific language governing permissions and
// limitations under the License.
-#ifndef CRASHPAD_SNAPSHOT_MINIDUMP_MINIDUMP_STRING_READER_H_
-#define CRASHPAD_SNAPSHOT_MINIDUMP_MINIDUMP_STRING_READER_H_
+#ifndef CRASHPAD_SNAPSHOT_MINIDUMP_MINIDUMP_STRING_LIST_READER_H_
+#define CRASHPAD_SNAPSHOT_MINIDUMP_MINIDUMP_STRING_LIST_READER_H_
#include <windows.h>
#include <dbghelp.h>
#include <string>
+#include <vector>
#include "util/file/file_reader.h"
namespace crashpad {
namespace internal {
//! \brief Reads a MinidumpUTF8String from a minidump file at offset \a rva in
//! \a file_reader, and returns it in \a string.
//!
-//! \return `true` on success, with \a string set. `false` on failure, with a
-//! message logged.
-bool ReadMinidumpUTF8String(FileReaderInterface* file_reader,
- RVA rva,
- std::string* string);
+//! \return `true` on success, with \a list set by replacing its contents.
+//! `false` on failure, with a message logged.
+bool ReadMinidumpStringList(FileReaderInterface* file_reader,
+ const MINIDUMP_LOCATION_DESCRIPTOR& location,
+ std::vector<std::string>* list);
} // namespace internal
} // namespace crashpad
-#endif // CRASHPAD_SNAPSHOT_MINIDUMP_MINIDUMP_STRING_READER_H_
+#endif // CRASHPAD_SNAPSHOT_MINIDUMP_MINIDUMP_STRING_LIST_READER_H_
« no previous file with comments | « snapshot/minidump/minidump_simple_string_dictionary_reader.cc ('k') | snapshot/minidump/minidump_string_list_reader.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -12,29 +12,31 @@
namespace crashpad {
namespace internal {
-//! \brief Reads a MinidumpUTF8String from a minidump file at offset \a rva in
-//! \a file_reader, and returns it in \a string.
+//! \brief Reads a list of MinidumpUTF8String objects in a MinidumpRVAList from
+//! a minidump file \a location in \a file_reader, and returns it in \a
+//! list.
//!
This is Rietveld 408576698